TinyXml: TiXmlVisitor Class Reference

# TiXmlVisitor Class Reference

Implements the interface to the "Visitor pattern" (see the Accept() method. More...

`#include <tinyxml.h>`

Inheritance diagram for TiXmlVisitor:

List of all members.

## Public Member Functions
virtual bool | VisitEnter (const TiXmlDocument &)
| Visit a document.
virtual bool | VisitExit (const TiXmlDocument &)
| Visit a document.
virtual bool | VisitEnter (const TiXmlElement &, const TiXmlAttribute *)
| Visit an element.
virtual bool | VisitExit (const TiXmlElement &)
| Visit an element.
virtual bool | Visit (const TiXmlDeclaration &)
| Visit a declaration.
virtual bool | Visit (const TiXmlText &)
| Visit a text node.
virtual bool | Visit (const TiXmlComment &)
| Visit a comment node.
virtual bool | Visit (const TiXmlUnknown &)
| Visit an unknown node.

## Detailed Description

Implements the interface to the "Visitor pattern" (see the Accept() method.

) If you call the Accept() method, it requires being passed a TiXmlVisitor class to handle callbacks. For nodes that contain other nodes (Document, Element) you will get called with a VisitEnter/VisitExit pair. Nodes that are always leaves are simply called with Visit().

If you return 'true' from a Visit method, recursive parsing will continue. If you return false, no children of this node or its sibilings will be Visited.

All flavors of Visit methods have a default implementation that returns 'true' (continue visiting). You need to only override methods that are interesting to you.

Generally Accept() is called on the TiXmlDocument, although all nodes suppert Visiting.

You should never change the document from a callback.

See also:
  TiXmlNode::Accept()

The documentation for this class was generated from the following file:

- tinyxml.h